/**********************************************************************************/
/*                                                                                */
/*        Copyright (C) 2005, WiNRADiO Communications, All Rights Reserved        */
/*                                                                                */
/**********************************************************************************/

#ifndef __U_MAIN_WINDOW_H__
#define __U_MAIN_WINDOW_H__

#include <wx/wx.h>
#include "u_freqedit.h"
#include "wrg313api.h"


class TSpectrum;

class TMainWindow:public wxFrame
{
public:
    void OnIFShiftChanged(int NewIFShift);
    void OnIFBandwidthChanged(int NewIFBandwidth);

    static void SpectrumCallback(float *Buffer,int Count,void* UserData);
    static void AudioCallback(short *Buffer,int Count,void *UserData);

    inline bool IsAudioOpened(void)
    {
        return m_Audio>=0;
    }

    TMainWindow(int hRadio,const wxString &Path);
    ~TMainWindow(void);
private:
    wxString        m_Serial;
    int             m_hRadio;
    wxString        m_Path;
    RADIO_INFO      m_Info;
    TFreqEdit       *m_FreqEdit;
    wxString        m_Buffer;
    bool            m_DontModifyFreq;
    int             m_Mode;
    int             m_Audio;
    
    wxButton        *m_CloseButton;
    
    wxButton        *m_AM;
    wxButton        *m_AMS;
    wxButton        *m_LSB;
    wxButton        *m_USB;
    wxButton        *m_ISB;
    wxButton        *m_DSB;
    wxButton        *m_CW;
    wxButton        *m_FM;
    
    wxButton        *m_Buttons[8];
    
    wxStaticText    *m_ModeText;
    wxStaticText    *m_IF1AGCText;
    wxStaticText    *m_SoftAGCText;
    wxStaticBox     *m_SoftAGCBox;
    
    wxSlider        *m_IF1Gain;
    wxStaticText    *m_IF1GainText;
    wxStaticBox     *m_IF1GainBox;
    
    wxSlider        *m_Volume;
    wxStaticText    *m_VolumeText;
    
    
    wxButton        *m_SoftAGCButtons[4];
    
    wxTextCtrl      *m_IFBandwidth;
    wxTextCtrl      *m_IFShift;
    
    TSpectrum       *m_Spectrum;
        
    wxTimer         m_Timer;
    wxTimer         m_Timer2;
    
    int             m_NewBandwidth;
    int             m_NewBandwidthMode;
    
    bool            m_SpectrumChanged;
    float           m_SpectrumData[1024];
    pthread_mutex_t m_Mutex;
    
    bool StrFreqToL(const char *freq,unsigned long long *Value,TFreqUnits *Units);
    
    
    
    
    void OnClose(wxCommandEvent& event);
    void OnFreqChanged(wxCommandEvent& event);
    void OnMode(wxCommandEvent& event);
    
    void OnIF1AGC(wxCommandEvent& event);
    void OnSAGC(wxCommandEvent& event);
        
    void OnIF1Gain(wxCommandEvent &event);
    void OnVolume(wxCommandEvent &event);
    
    void OnIFShiftEnter(wxCommandEvent &event);
    void OnIFBandwidthEnter(wxCommandEvent &event);
    
    void SaveSettings(void);
    void LoadSettings(void);
    
    
    void UpdateVolumeText(void);
    void UpdateIF1GainText(void);
    void UpdateSAGCText(void);
    void UpdateIF1AGCText(void);
    void UpdateModeText(void);
    
    void OnTimer(wxTimerEvent& event);
    void OnTimer2(wxTimerEvent& event);
    
    void SpectrumCallback(float *Buffer,int Count);
    void AudioCallback(short *Buffer,int Count);
    void UpdateIF(void);
    
    DECLARE_EVENT_TABLE()
};



#endif
