#!/bin/sh

OS=`uname -s 2>/dev/null`
PLATFORM=`uname -i 2>/dev/null`
WiNRADiO_RULES="/etc/udev/rules.d/WiNRADiO.rules"


echo ""
echo "WiNRADiO G313 driver and API installation"
echo ""

if [ $(id -ur) != 0 ]; then
    echo "Please, run this installer as root."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

if [ "$OS" != "Linux" ]; then
    echo "Your operating system is not supported."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

if [ "$PLATFORM" != "i386" && "$PLATFORM" != "i486" && "$PLATFORM" != "i586" && "$PLATFORM" != "i686" ]; then
    echo "Your hardware platform is not supported."
    echo "i386/i486/i586/i686 hardware platform is required."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

echo "Compiling G313 kernel module"

cd "driver"

if [ $? != 0 ]; then
    echo "Could not find G313 driver source code."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

make clean
make

echo ""

if [ ! -f "wrg313.ko" ]; then
    cd ..
    echo "Compilation of G313 kernel module failed."
    echo "Please, check if development tools and development package"
    echo "for building kernel modules are installed and check if your kernel"
    echo "supports loadable modules."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

echo "Writing udev rule"

if [ -f "$WiNRADiO_RULES" ]; then
	WRG3=`less "$WiNRADiO_RULES" | grep wrg3`
	
	if [ -z "$WRG3" ]; then
	    if [ -s "$WiNRADiO_RULES" ]; then
    		echo "" >> "$WiNRADiO_RULES"
    	    fi
	
    	    echo "# WiNRADiO G3xx devices" >> "$WiNRADiO_RULES"
	    echo 'KERNEL=="wrg3*"				MODE="0644"' >> "$WiNRADiO_RULES"
	else
	    echo "G313 udev rule exists."	    
	fi
else
	echo "# WiNRADiO G3xx devices" > "$WiNRADiO_RULES"
	echo 'KERNEL=="wrg3*"				MODE="0644"' >> "$WiNRADiO_RULES"
fi

echo "Installing G313 kernel module"
make uninstall >/dev/null 2>&1
make install



if [ $? != 0 ]; then
    cd ..

    echo ""

    echo "G313 kernel module installation failed."
    echo "Installation aborted."
    echo ""
    echo "Press ENTER to exit."
    read tmp
    exit 1
fi

cd ..

echo ""

/sbin/depmod -a
/sbin/modprobe wrg313

echo "Installing G313 API"

install -m 755 lib/wrg313api.so /usr/lib

if [ $? != 0 ]; then
	echo "Installation of G313 API failed."
	echo "Installation aborted."
	echo ""
	echo "Press ENTER to exit."
	read tmp
	exit 1
fi

echo "G313 API (wrg313api.so) installed to /usr/lib"


echo ""
echo "Done."
echo ""
echo "Press ENTER to exit."
read tmp

exit 0